# Generated by Django 4.2.10 on 2024-04-08 12:24

import json
import re
from django.db import migrations, models
import scipost.fields


def convert_acceptance_criteria_text_to_json(apps, schema_editor):
    Journal = apps.get_model("journals", "Journal")
    for journal in Journal.objects.all():
        previous_acceptance_criteria = journal.acceptance_criteria
        acceptance_criteria = {"preamble": "", "sections": []}

        preamble = re.match(
            r"^(.+?)(?:\*\*|$)", previous_acceptance_criteria, re.DOTALL
        )
        if preamble:
            acceptance_criteria["preamble"] = preamble.group(0).strip()

        for title, criteria in re.findall(
            r"\*\*(.*?)\*\*\r\n(.*?)(?:\r\n\r\n|$)",
            previous_acceptance_criteria,
            re.DOTALL,
        ):
            section = {
                "title": title,
                "type": (
                    "expectations"
                    if "expectations" in title.lower()
                    else "general_acceptance"
                ),
                "criteria": {
                    str(i): criterion.strip()
                    for i, criterion in enumerate(
                        re.findall(
                            r"(?:#\. |\*)?(.+?)$", criteria.strip(), re.MULTILINE
                        )
                    )
                },
            }

            acceptance_criteria["sections"].append(section)

        journal.acceptance_criteria = json.dumps(acceptance_criteria)
        journal.save()


class Migration(migrations.Migration):
    dependencies = [
        ("journals", "0130_remove_publication_pubfractions_confirmed_by_authors"),
    ]

    operations = [
        migrations.RunPython(
            convert_acceptance_criteria_text_to_json,
            reverse_code=migrations.RunPython.noop,
        ),
        migrations.AlterField(
            model_name="journal",
            name="acceptance_criteria",
            field=models.JSONField(
                default={
                    "preamble": "Text before the list(s)",
                    "sections": [
                        {
                            "criteria": {
                                "1": "First criterion",
                                "2": "Second criterion",
                            },
                            "title": "First section",
                            "type": "expectations",
                        },
                        {
                            "criteria": {
                                "1": "First criterion",
                                "2": "Second criterion",
                            },
                            "title": "Second section",
                            "type": "general_acceptance",
                        },
                    ],
                }
            ),
        ),
        migrations.AlterField(
            model_name="publication",
            name="approaches",
            field=scipost.fields.ChoiceArrayField(
                base_field=models.CharField(
                    choices=[
                        ("theoretical", "Theoretical"),
                        ("experimental", "Experimental"),
                        ("computational", "Computational"),
                        ("phenomenological", "Phenomenological"),
                        ("observational", "Observational"),
                        ("clinical", "Clinical"),
                    ],
                    max_length=24,
                ),
                blank=True,
                null=True,
                size=None,
            ),
        ),
    ]
